#!/bin/bash

die () {
  echo -ne "$1"
  exit 1
}

# 1 - environment
[ -z "$TAXON_DATA" -o -z "$TAXON_DATA_GZ" -o -z "$TAXON_DB" -o -z "$TAXON_DBHOST" -o -z "$TAXON_DBUSER" ] &&
  die "Environment not set.\nSource the taxon.config file.\n" 
[ ! -d "$TAXON_DATA" -o ! -d "$TAXON_DATA_GZ" ] && 
  die "Data folders don't exist.\nMake the folders specified by the TAXON environment variables.\n"

# 2 - tar file
[ ! -f "$TAXON_DATA_GZ"/taxdump.tar.gz ] && 
  die "Taxonomy tar file does not exist.\nDownload from the NCBI.\n"
[ ! -f "$TAXON_DATA"/names.dmp -a ! -f "$TAXON_DATA"/nodes.dmp ] && 
  die "Taxonomy name and/or node files do not exist.\nUntar file.\n"
[ ! -s "$TAXON_DATA"/names.dmp -a ! -s "$TAXON_DATA"/nodes.dmp ] && 
  die "Taxonomy name and/or node files do not contain data.\nHave a look at the files and the tar file.\n"

# 3 - database
echo "" | mysql -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" test >& /dev/null || 
  die "Cannot connect to database server.\nCheck that the hostname and dbuser are correct in the taxon.config file.\n"
echo "" | mysql -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" "$TAXON_DB" >& /dev/null || 
  die "Cannot open database $TAXON_DB.\nCheck to be sure the database exists and that the permissions are correct\n."

# 4 - tables
echo "select * from names limit 0;" | mysql -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" "$TAXON_DB" >& /dev/null || 
  die "Table 'names' does not exist.\n"
foo=$(echo "select count(*) from names ;" | mysql -s -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" "$TAXON_DB") &&
  [ $foo -gt 0 ] ||
  die "Table 'names' doesn't contain data\n."
echo "select * from nodes limit 0;" | mysql -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" "$TAXON_DB" >& /dev/null || 
  die "Table 'nodes' does not exist.\n"
foo=$(echo "select count(*) from nodes ;" | mysql -s -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" "$TAXON_DB") &&
  [ $foo -gt 0 ] ||
  die "Table 'nodes' doesn't contain data\n."

# if any tests fail run create.table.names and create.table.nodes

echo "all's well."

cat <<! > /dev/null
4 - create and load data into the tables
    test: does names table exist?
    test: does names table contain data?
    test: does nodes table exist?
    test: does nodes table contain data?
    run create.table.names create.table.nodes
5 - create nested set of nodes data and load into database
    test: does nsn table exist?
    test: does nsn table contain data?
    test: do the references exist?
    run number.nsn 1 1
6 - add index to nested_set_of_nodes
    test: is the nsn table indexed?
    echo "alter table nested_set_of_nodes add index (lft), add index (rgt)" | 
      mysql -h localhost -u bio mgb 
7 - test
    run query.demo
8 - move to mgb
    run tfer.to.mgb


TAXON_DATA=./data
TAXON_DATA_GZ=./data
TAXON_DB=taxon
TAXON_DBHOST=orion2
TAXON_DBUSER=bio
!
 
