#!/bin/bash

# (c) 2004 - Robert Citek - Orion Genomics, LLC

die () {
  echo -ne "$1"
  exit 1
}

initialize () {
 . taxon.config
}

setup () {
  for i in "$TAXON_DATA" "$TAXON_DATA_GZ"  ; do
    [ -n "$i" ] && [ ! -d "$i" ] && 
      { mkdir -p "$i" || die "Couldn't make directory $i\n" ; }
  done
}

extract () {
  [ ! -f "$TAXON_DATA_GZ"/taxdump.tar.gz ] && 
    die "Taxonomy tar file does not exist.\n"
  tar -xzf "$TAXON_DATA_GZ"/taxdump.tar.gz -C "$TAXON_DATA" names.dmp nodes.dmp
}

create_database () {
  echo "drop database if exists $TAXON_DB ; create database $TAXON_DB ; " | 
  mysql -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" >& /dev/null ||
  die "Could not create database.\n"
}

create_tables_names () {

# creates the table "names" in the database taxonomy
# and loads the data from the NCBI names.dmp file

names_dmp="~rwcitek/src/dbtree/data/names.dmp"
local=local

{ cat <<!
drop table if exists names;
create table if not exists names (
  tax_id mediumint not null,
  name_txt varchar(30),
  unique_name varchar(30),
  name_class varchar(30),
  index (tax_id)
);
load data $local infile '$names_dmp'
  into table names
  fields terminated by "\t|\t"
  lines terminated by "\t|\n" ;
!
} | mysql -h "$TAXON_DBHOST" -u "$TAXON_DBUSER" "$TAXON_DB" >& /dev/null ||
  die "Could not create table names.\n"
  unset names_dmp
  unset local
}

###  main 
# initialize
# create_tables_names


